pub struct ComponentRoot { /* private fields */ }Implementations
Sourceimpl ComponentRoot
impl ComponentRoot
pub fn new(file_name: Option<String>, components: Vec<Component>) -> Self
Sourcepub fn children(&self) -> Vec<&Component>
pub fn children(&self) -> Vec<&Component>
Examples found in repository?
examples/demo.rs (line 89)
74 fn draw(&mut self, frame: &mut Frame) {
75 self.area = frame.area();
76
77 self.markdown = Some(parser::parse_markdown(None, CONTENT, self.area.width));
78
79 if let Some(markdown) = &mut self.markdown {
80 markdown.set_scroll(self.scroll);
81
82 let area = Rect {
83 width: self.area.width - 1,
84 height: self.area.height - 1,
85 x: 1,
86 ..self.area
87 };
88
89 for child in markdown.children() {
90 if let Component::TextComponent(comp) = child {
91 if comp.y_offset().saturating_sub(comp.scroll_offset()) >= area.height
92 || (comp.y_offset() + comp.height()).saturating_sub(comp.scroll_offset())
93 == 0
94 {
95 continue;
96 }
97
98 frame.render_widget(comp.clone(), area);
99 }
100 }
101 }
102 }pub fn children_mut(&mut self) -> Vec<&mut Component>
pub fn components(&self) -> Vec<&TextComponent>
pub fn components_mut(&mut self) -> Vec<&mut TextComponent>
pub fn file_name(&self) -> Option<&str>
pub fn words(&self) -> Vec<&Word>
pub fn find_and_mark(&mut self, search: &str)
pub fn search_results_heights(&self) -> Vec<usize>
pub fn clear(&mut self)
pub fn select(&mut self, index: usize) -> Result<u16, String>
pub fn deselect(&mut self)
pub fn find_footnote(&self, search: &str) -> String
pub fn link_index_and_height(&self) -> Vec<(usize, u16)>
Sourcepub fn set_scroll(&mut self, scroll: u16)
pub fn set_scroll(&mut self, scroll: u16)
Sets the y offset of the components
Examples found in repository?
examples/demo.rs (line 80)
74 fn draw(&mut self, frame: &mut Frame) {
75 self.area = frame.area();
76
77 self.markdown = Some(parser::parse_markdown(None, CONTENT, self.area.width));
78
79 if let Some(markdown) = &mut self.markdown {
80 markdown.set_scroll(self.scroll);
81
82 let area = Rect {
83 width: self.area.width - 1,
84 height: self.area.height - 1,
85 x: 1,
86 ..self.area
87 };
88
89 for child in markdown.children() {
90 if let Component::TextComponent(comp) = child {
91 if comp.y_offset().saturating_sub(comp.scroll_offset()) >= area.height
92 || (comp.y_offset() + comp.height()).saturating_sub(comp.scroll_offset())
93 == 0
94 {
95 continue;
96 }
97
98 frame.render_widget(comp.clone(), area);
99 }
100 }
101 }
102 }pub fn heading_offset(&self, heading: &str) -> Result<u16, String>
Sourcepub fn content(&self) -> Vec<String>
pub fn content(&self) -> Vec<String>
Return the content of the components, where each element a line
pub fn selected(&self) -> &str
pub fn selected_underlying_type(&self) -> WordType
Sourcepub fn transform(&mut self, width: u16)
pub fn transform(&mut self, width: u16)
Transforms the content of the components to fit the given width
Sourcepub fn add_missing_components(self) -> Self
pub fn add_missing_components(self) -> Self
Because of the parsing, every table has a missing newline at the end
Sourcepub fn height(&self) -> u16
pub fn height(&self) -> u16
Examples found in repository?
examples/demo.rs (line 56)
54 fn scroll_down(&mut self) -> bool {
55 if let Some(markdown) = &self.markdown {
56 let len = markdown.height();
57 if self.area.height > len {
58 self.scroll = 0;
59 } else {
60 self.scroll = std::cmp::min(
61 self.scroll.saturating_add(1),
62 len.saturating_sub(self.area.height),
63 )
64 }
65 }
66 true
67 }pub fn num_links(&self) -> usize